==> react-canvas-timeline-0.0.24.tgz: package/src/stories/04_timeline_taskbackground.stories.js <==
import React, {useState} from 'react';
import ReactCanvasTimeline from '../timeline/reactcanvastimeline'
import buildTestData from './testdatabuilder';

export default {
  title: 'timeline',
  component: ReactCanvasTimeline,
};

export const _4AgreedTimesTimeline = () => {
  let testData = buildTestData();
  const [selectedTaskIDs, setSelectedTaskIDs] = useState([]);

  const timelineClicked = (evt) => {
    if (evt.task) {

      let newArr = [...selectedTaskIDs];
      if (selectedTaskIDs.includes(evt.task.id)) {
        newArr.splice(newArr.indexOf(evt.task.id), 1);
      } else {
        newArr.push(evt.task.id);
      }
      setSelectedTaskIDs(newArr);
    }
  }

  const taskBackgroundPainter = (ctx, timeline, task) => {

    if (task && selectedTaskIDs.includes(task.id)) {
      let xStart = timeline.getXPosForTime(
          timeline.getModel().getDisplayedStart(task).getJulianMinutes());
      if (xStart <= timeline.virtualCanvasWidth) {
        let xEnd = timeline.getXPosForTime(
            timeline.getModel().getDisplayedEnd(task).getJulianMinutes());
        if (xEnd > timeline.resourceHeaderHeight) {
          let resStartY = timeline.timelineHeaderHeight
              + timeline.getModel().getRelativeYStart(task.getID())
              + timeline.workResOffset;
          ctx.fillStyle = "rgba(0, 255, 0.4)";

          ctx.fillRect(xStart - 40, resStartY, xEnd - xStart + 80,
              timeline.getModel().getHeight(task.getID()));
        }
      }
    }
  }

    return <div>
      Click task to see colored area in the background (e.g. for agreed times or bankholidays)
      <br/>
      <br/>
      <ReactCanvasTimeline
          resources={testData.resources}
          tasks={testData.tasks}
          initialBarSize={40}
          taskBackgroundPainter={taskBackgroundPainter}
          paintShadows = {true}
          onClick={(evt) => timelineClicked(evt)}
          //onPress={(evt) => console.log(evt)}
          //onLongPress={(evt) => console.log(evt)}
          //onZoomChange={(startLCal, endLCal) => console.log("Zoom changed: " + startLCal + " - " + endLCal)}
          //onMouseMove={(evt) => console.log(evt)}
      />
    </div>;
  }

==> react-canvas-timeline-0.0.30.tgz: package/src/stories/04_timeline_taskbackground.stories.js <==
import React, {useState} from 'react';
import ReactCanvasTimeline from '../timeline/reactcanvastimeline'
import buildTestData from './testdatabuilder';

export default {
  title: 'timeline',
  component: ReactCanvasTimeline,
};

export const _4AgreedTimesTimeline = () => {
  let testData = buildTestData();
  const [selectedTaskIDs, setSelectedTaskIDs] = useState([]);

  const timelineClicked = (evt) => {
    if (evt.task) {

      let newArr = [...selectedTaskIDs];
      if (selectedTaskIDs.includes(evt.task.id)) {
        newArr.splice(newArr.indexOf(evt.task.id), 1);
      } else {
        newArr.push(evt.task.id);
      }
      setSelectedTaskIDs(newArr);
    }
  }

  const taskBackgroundPainter = (ctx, timeline, task) => {

    if (task && selectedTaskIDs.includes(task.id)) {
      let xStart = timeline.getXPosForTime(
          timeline.getModel().getDisplayedStart(task).getJulianMinutes());
      if (xStart <= timeline.virtualCanvasWidth) {
        let xEnd = timeline.getXPosForTime(
            timeline.getModel().getDisplayedEnd(task).getJulianMinutes());
        if (xEnd > timeline.resourceHeaderHeight) {
          let resStartY = timeline.timelineHeaderHeight
              + timeline.getModel().getRelativeYStart(task.getID())
              + timeline.workResOffset;
          ctx.fillStyle = "rgba(0, 255, 0, 0.5)";

          ctx.fillRect(xStart - 40, resStartY, xEnd - xStart + 80,
              timeline.getModel().getHeight(task.getID()));
        }
      }
    }
  }

    return <div>
      Click task to see colored area in the background (e.g. for agreed times or bankholidays)
      <br/>
      <br/>
      <ReactCanvasTimeline
          resources={testData.resources}
          tasks={testData.tasks}
          initialBarSize={40}
          taskBackgroundPainter={taskBackgroundPainter}
          paintShadows = {true}
          onClick={(evt) => timelineClicked(evt)}
      />
    </div>;
  }
